/*
 * File: background.js
 * Project: extension
 * Created: 2024-12-10 04:44:30
 * Author: Victor Cheng
 * Email: greenzorromail@gmail.com
 * Description: 
 */

/**
 * 插件安装时触发的回调函数
 */
chrome.runtime.onInstalled.addListener(() => {
  console.log('Music Playlist Migration extension installed');
});

/**
 * 监听来自content script的消息，并在收到消息时调用 Cloudflare Worker 的上传接口
 */
chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
  if (message.action === 'uploadToWorker') {
    console.log('Received message from content script:', message);

    // 从 message.content 中获取 stats 数据
    console.log('Statistics received:', message.content.stats);

    // 直接调用 Cloudflare Worker 的上传接口
    uploadToWorker(message.content)
      .then(response => {
        console.log("Response from worker:", response);
        sendResponse({ result: response.url })
      })
      .catch(error => {
        console.error("Error uploading to worker:", error);
        sendResponse({ error: error.message })
      });

    return true; // 表示我们将异步发送响应

  } else if (message.action === 'download') { // 将 request 改为 message
    console.log("Downloading file:", message.filename);
    chrome.downloads.download({
      url: message.blobUrl, // 使用 message.blobUrl
      filename: message.filename // 使用 message.filename
    }, (downloadId) => {
      if (chrome.runtime.lastError) {
        sendResponse({ success: false, error: chrome.runtime.lastError.message });
      } else {
        sendResponse({ success: true, downloadId: downloadId });
      }
    });
    return true; // 表示异步响应
  }
});

/**
 * 将HTML内容上传到 Cloudflare Worker
 * @param {{htmlContent: string, stats: object}} data 要上传的HTML内容和统计数据
 * @returns {Promise<any>} 包含 Cloudflare Worker 返回的URL的对象
 */
async function uploadToWorker(data) {
  console.log('uploadToWorker started working');
  const url = 'https://playlist-upload.victor42.work';
  console.log('Sending request to:', url);

  const controller = new AbortController();
  const timeoutId = setTimeout(() => {
    console.log('Timeout triggered');
    controller.abort('Request timed out');
  }, 5000); // 5 秒超时

  try {
    const response = await fetch(url, {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json' // 修改 Content-Type 为 application/json
      },
      body: JSON.stringify(data), // 将数据对象转换为 JSON 字符串
      signal: controller.signal
    });

    clearTimeout(timeoutId);

    if (!response.ok) {
      // 添加提示信息：HTTP 错误
      const errorMsg = `HTTP error! status: ${response.status}`;
      console.error(errorMsg);
      throw new Error(errorMsg);
    }

    const result = await response.json();
    // 添加提示信息：上传成功，但返回结果为空
    if (!result || Object.keys(result).length === 0) {
      console.warn('上传成功，但返回结果为空。');
    }
    return result;
  } catch (error) {
    if (error.name === 'AbortError') {
      // 添加提示信息：请求超时
      console.error('请求超时，请检查网络连接或稍后重试。');
    } else {
      console.error('Error uploading to worker:', error);
    }
    throw error;
  }
}

console.log('Background script loaded and running'); // 添加调试信息
