/*
 * File: content.js
 * Project: extension
 * Created: 2024-12-10 06:12:01
 * Author: Victor Cheng
 * Email: greenzorromail@gmail.com
 * Description: 这是一个用于迁移歌单的浏览器扩展程序的内容脚本。
 */

// 全局变量，表示当前页面的 URL 和目标平台
let currentUrl = window.location.href;
let srcPlatform = platformManager.getCurrentPlatform();
let dstPlatform = null;
let isProcessing = false; //标记二维码迁移是否在进行中

/**
 * 在页面上添加一个用于触发歌单迁移的按钮。
 */
function addMigrateButton() {
  // console.log("addMigrateButton: 添加迁移按钮");
  const button = document.createElement('a');
  button.style.display = 'flex';
  button.style.flexDirection = 'column';
  button.style.alignItems = 'center';
  button.style.position = 'fixed';
  button.style.top = '50%';
  button.style.right = '0';
  button.style.transform = 'translateY(-50%)';
  button.style.backgroundColor = '#EA4C5A';
  button.style.padding = '12px';
  button.style.borderTopLeftRadius = '20px';
  button.style.borderBottomLeftRadius = '20px';
  button.style.textDecoration = 'none';
  button.style.zIndex = '9999';
  button.style.cursor = 'pointer';
  button.addEventListener('click', btnAction);

  const logo = document.createElement('img');
  logo.src = chrome.runtime.getURL('assets/logo.png');
  logo.style.marginBottom = '4px';
  logo.style.width = '40px';
  button.appendChild(logo);

  const text = document.createElement('span');
  text.textContent = '搬家';
  text.style.color = 'white';
  text.style.fontSize = '14px';
  text.style.fontWeight = '500';
  text.style.textAlign = 'center';
  button.appendChild(text);

  document.body.appendChild(button);
  // console.log("addMigrateButton: 迁移按钮添加完成");
}

/**
 * 迁移按钮的点击事件处理函数。
 * 检查用户是否登录，如果未登录则提示用户登录。
 * 检查是否已存在迁移对话框，如果已存在则直接返回。
 * 提取当前页面的歌单信息，如果歌单为空则提示用户。
 * 清理歌单名称和歌曲名中的非法字符，并显示迁移对话框。
 */
async function btnAction() {
  // console.log("btnAction: 迁移按钮被点击");
  // 更新 srcPlatform
  srcPlatform = platformManager.getCurrentPlatform();
  // console.log(`btnAction: 当前平台为 ${srcPlatform}`);

  if (!platformManager.isUserLoggedIn(srcPlatform)) {
    // console.log("btnAction: 用户未登录");
    showToast('请登录以迁移完整歌单。');
    return;
  }

  if (!platformManager.isSupportedPage()) {
    // console.log("btnAction: 当前页面不是歌单页面");
    showToast('请前往你的歌单页面。');
    return;
  }

  // 检查是否已经存在迁移对话框
  if (document.getElementById('migration-dialog')) {
    // console.log("btnAction: 迁移对话框已存在，更新对话框内容");
    // 如果已存在，则更新对话框内容
    updateMigrationDialog();
    return;
  }

  let [songList_name, songList] = await platformManager.extractSongList(srcPlatform);
  // console.log(`btnAction: 提取歌单信息，歌单名称为 ${songList_name}，歌曲数量为 ${songList.length}`);

  if (songList.length === 0) {
    // console.log("btnAction: 歌单为空");
    showToast('在歌单中找不到歌曲。请确保您在歌单页面。');
    return;
  } else {
    // 清理歌单名称和歌曲名中的非法字符
    songList.forEach(song => {
      song.name = window.utils.sanitizeFileName(song.name);
      song.artist = window.utils.sanitizeFileName(song.artist);
    });
    // console.log("btnAction: 歌单名称和歌曲名已清理");
  }

  showMigrationDialog(songList_name, songList);
  // console.log("btnAction: 显示迁移对话框");
}

/**
 * 显示迁移对话框。
 * 加载 popup.html 和 popup.css。
 * 创建对话框元素并添加到页面中。
 * 动态插入目标平台图标，并为每个图标添加点击事件监听器。
 * 添加关闭按钮事件。
 * @param {string} songList_name 歌单名称
 * @param {Array} songList 歌曲列表
 */
async function showMigrationDialog(songList_name, songList) {
  // console.log("showMigrationDialog: 开始显示迁移对话框");
  let response;
  try {
    // console.log("showMigrationDialog: 尝试获取 popup.html");
    response = await fetch(chrome.runtime.getURL('ui/popup.html'));
  } catch (error) {
    console.error("showMigrationDialog: 获取 popup.html 失败:", error);
    return;
  }
  const html = await response.text();
  // console.log("showMigrationDialog: popup.html 获取成功");

  // 使用 DOMParser 解析 HTML
  const parser = new DOMParser();
  const doc = parser.parseFromString(html, 'text/html');
  // console.log("showMigrationDialog: popup.html 解析完成");

  // 加载 popup.css 文件
  const linkElement = document.createElement('link');
  linkElement.rel = 'stylesheet';
  linkElement.href = chrome.runtime.getURL('ui/popup.css');
  document.head.appendChild(linkElement);
  // console.log("showMigrationDialog: popup.css 加载完成");

  // 获取 bg.jpg 的绝对路径
  const bgUrl = chrome.runtime.getURL('assets/bg.jpg');
  // console.log(`showMigrationDialog: bg.jpg 的路径为 ${bgUrl}`);

  // 创建对话框元素
  const dialog = document.createElement('div');
  dialog.id = 'migration-dialog';
  dialog.style.position = 'fixed';
  dialog.style.top = '50%';
  dialog.style.left = '50%';
  dialog.style.transform = 'translate(-50%, -50%)';
  dialog.style.zIndex = '10000';
  dialog.style.display = 'none'; // 初始状态设置为隐藏
  dialog.innerHTML = doc.body.innerHTML;
  // console.log("showMigrationDialog: 对话框元素创建完成");

  // 动态插入目标平台图标
  const platformIconsContainer = dialog.querySelector('#platformIcons');
  platformIconsContainer.innerHTML = ''; // 清空平台图标容器
  const platforms = [
    { name: 'QQ音乐', icon: 'dst-qq.png', value: platformManager.Platforms.QQ },
    { name: '网易云音乐', icon: 'dst-netease.png', value: platformManager.Platforms.NETEASE }
  ];
  // console.log("showMigrationDialog: 目标平台图标数据准备完成");

  // 尝试从本地存储中读取用户上次选择的目标平台
  chrome.storage.local.get('dstPlatform', (data) => {
    const savedDstPlatform = data.dstPlatform;
    // console.log(`showMigrationDialog: 从本地存储中读取上次选择的目标平台: ${savedDstPlatform}`);

    // 重新获取 platformIconsContainer，因为它现在在 dialog 中
    const platformIconsContainerInDialog = dialog.querySelector('#platformIcons');

    platforms.forEach(platform => {
      const platformLink = document.createElement('a');
      platformLink.href = '#';
      platformLink.classList.add('platform-link');
      platformLink.addEventListener('click', (event) => {
        event.preventDefault();
        // console.log(`showMigrationDialog: 目标平台 ${platform.name} 被点击`);
        // 移除所有平台的选中状态
        platformIconsContainerInDialog.querySelectorAll('.platform-link').forEach(link => link.classList.remove('selected'));
        // 为当前点击的平台添加选中状态
        platformLink.classList.add('selected');
        // 更新 dstPlatform 变量
        dstPlatform = platform.value;
        // console.log(`showMigrationDialog: 目标平台已设置为 ${dstPlatform}`);
        // 将用户的选择保存在本地存储中
        chrome.storage.local.set({ dstPlatform: dstPlatform });
        // console.log(`showMigrationDialog: 目标平台已保存到本地存储`);
        // 显示迁移方式选项
        showMigrationOptions(dialog, songList_name, songList);
      });

      const platformIcon = document.createElement('img');
      platformIcon.classList.add('platform-icon');
      platformIcon.src = chrome.runtime.getURL(`assets/${platform.icon}`);
      platformIcon.alt = platform.name;

      platformLink.appendChild(platformIcon);
      platformIconsContainerInDialog.appendChild(platformLink);
      // console.log(`showMigrationDialog: 目标平台 ${platform.name} 图标已添加`);

      // 如果当前平台是用户上次选择的平台，则自动选中
      if (savedDstPlatform === platform.value) {
        platformLink.classList.add('selected');
        dstPlatform = platform.value;
        // console.log(`showMigrationDialog: 目标平台 ${platform.name} 自动选中`);
        // 自动显示迁移方式选项
        showMigrationOptions(dialog, songList_name, songList);
      }
    });
  });

  // 添加关闭按钮事件
  const closeButton = dialog.querySelector('.close-btn');
  closeButton.addEventListener('click', () => {
    // console.log("showMigrationDialog: 关闭按钮被点击");
    document.body.removeChild(dialog);
    // 移除添加到页面的 link 标签
    document.head.removeChild(linkElement);
    // console.log("showMigrationDialog: 对话框已关闭");
  });

  // 将对话框添加到页面中
  document.body.appendChild(dialog);
  // console.log("showMigrationDialog: 对话框已添加到页面");

  // 等待样式加载完成
  await new Promise(resolve => {
    if (linkElement.sheet) {
      resolve();
    } else {
      linkElement.onload = resolve;
    }
  });
  // console.log("showMigrationDialog: 样式加载完成");

  // 样式加载完成后显示对话框
  dialog.style.display = 'block';
  // console.log("showMigrationDialog: 对话框显示");

  // 将 bgUrl 通过 postMessage 传递给 popup.html
  const iframe = document.createElement('iframe');
  iframe.style.display = 'none';
  iframe.src = chrome.runtime.getURL('ui/popup.html');
  document.body.appendChild(iframe);
  iframe.contentWindow.postMessage({ type: 'bgUrl', url: bgUrl }, '*');
  // console.log("showMigrationDialog: bgUrl 已通过 postMessage 发送");
}

/**
 * 更新迁移对话框内容。
 * 重新提取当前页面的歌单信息。
 * 更新对话框中的歌单名称和歌曲列表。
 */
async function updateMigrationDialog() {
  // console.log("updateMigrationDialog: 开始更新迁移对话框");
  let [songList_name, songList] = await platformManager.extractSongList(srcPlatform);
  // console.log(`updateMigrationDialog: 提取歌单信息，歌单名称为 ${songList_name}，歌曲数量为 ${songList.length}`);

  if (songList.length === 0) {
    // console.log("updateMigrationDialog: 歌单为空");
    showToast('在歌单中找不到歌曲。请确保您在歌单页面。');
    return;
  } else {
    // 清理歌单名称和歌曲名中的非法字符
    songList.forEach(song => {
      song.name = window.utils.sanitizeFileName(song.name);
      song.artist = window.utils.sanitizeFileName(song.artist);
    });
    // console.log("updateMigrationDialog: 歌单名称和歌曲名已清理");
  }

  // 更新对话框中的歌单名称
  const dialog = document.getElementById('migration-dialog');
  const songListNameElement = dialog.querySelector('.songlist-name');
  if (songListNameElement) {
    songListNameElement.textContent = songList_name;
    // console.log(`updateMigrationDialog: 歌单名称已更新为 ${songList_name}`);
  }

  // 更新对话框中的歌曲列表（如果需要）
  // ...

  // 更新 handleFileMigration 函数中使用的数据
  const fileOption = dialog.querySelector('#fileOption');
  fileOption.onclick = (event) => {
    event.preventDefault();
    handleFileMigration(songList_name, songList);
    // console.log("updateMigrationDialog: 文件迁移选项已更新");
  };

  // 重新显示迁移方式选项
  showMigrationOptions(dialog, songList_name, songList);
  // console.log("updateMigrationDialog: 迁移方式选项已重新显示");
}

/**
 * 显示迁移方式选项（保存为文本文件或扫码迁移）。
 * 为“保存Txt文件”选项添加事件监听器。
 * 为“扫码搬家”选项添加事件监听器。
 * @param {HTMLElement} dialog 对话框元素
 * @param {string} songList_name 歌单名称
 * @param {Array} songList 歌曲列表
 */
function showMigrationOptions(dialog, songList_name, songList) {
  // console.log("showMigrationOptions: 显示迁移方式选项");
  // 显示迁移方式选项
  const optionsSection = dialog.querySelector('.options-section');
  optionsSection.style.display = 'block';
  // console.log("showMigrationOptions: 迁移方式选项区域已显示");

  // 为“保存Txt文件”选项添加事件监听器
  const fileOption = dialog.querySelector('#fileOption');
  fileOption.onclick = (event) => {
    event.preventDefault();
    handleFileMigration(songList_name, songList);
    // console.log("showMigrationOptions: 文件迁移选项被点击");
  };

  // 为“扫码搬家”选项添加事件监听器
  const qrOption = dialog.querySelector('#qrOption');
  qrOption.onclick = async (event) => {
    event.preventDefault();
    // console.log("showMigrationOptions: 扫码迁移选项被点击");
    // 显示二维码区域和加载动画
    const qrSection = dialog.querySelector('.qr-section');
    qrSection.style.display = 'block';
    const qrCodeContainer = dialog.querySelector('#qrCodeContainer');
    qrCodeContainer.innerHTML = ''; // 清空原有的内容
    qrCodeContainer.style.display = 'flex'; // 设置容器为 flex 布局
    qrCodeContainer.style.justifyContent = 'center'; // 水平居中
    qrCodeContainer.style.alignItems = 'center'; // 垂直居中
    // 添加加载动画图片
    const loadingImg = document.createElement('img');
    loadingImg.src = chrome.runtime.getURL('assets/loading.gif');
    loadingImg.style.width = '24px'; // 设置图片宽度
    loadingImg.style.height = '24px'; // 设置图片高度
    qrCodeContainer.appendChild(loadingImg);
    // console.log("showMigrationOptions: 二维码区域和加载动画已显示");

    await handleQRMigration(songList_name, songList);
  };
}

/**
 * 显示二维码。
 * 清空原有的二维码容器和加载动画。
 * 使用 qrcode.js 生成二维码。
 * @param {string} url 临时页面的URL
 */
async function showQRCode(url) {
  // console.log(`showQRCode: 显示二维码，URL 为 ${url}`);
  const dialog = document.getElementById('migration-dialog');

  // 显示二维码
  const qrSection = dialog.querySelector('.qr-section');
  qrSection.style.display = 'block';
  // console.log("showQRCode: 二维码区域已显示");

  // 清空原有的二维码容器和加载动画
  const qrCodeContainer = dialog.querySelector('#qrCodeContainer');
  qrCodeContainer.innerHTML = '';
  // console.log("showQRCode: 二维码容器已清空");

  // Generate QR code using qrcode.js
  window.utils.GenerateQRCode(qrCodeContainer, url, 120);
  // console.log("showQRCode: 二维码生成完成");
}

/**
 * 处理文件迁移操作。
 * 将歌单分组并格式化为文本。
 * 创建并下载文本文件。
 * @param {string} songList_name 歌单名称
 * @param {Array} songList 歌曲列表
 */
async function handleFileMigration(songList_name, songList) {
  // console.log("handleFileMigration: 开始处理文件迁移");
  const chunks = platformManager.chunkSongList(songList, dstPlatform);
  // console.log(`handleFileMigration: 歌单已分组，共 ${chunks.length} 组`);
  for (let index = 0; index < chunks.length; index++) {
    const chunk = chunks[index];
    const formattedSongList = platformManager.formatSongList(chunk, dstPlatform);
    const blob = new Blob([formattedSongList], { type: 'text/plain' });
    const fileName = chunks.length > 1 ? `${songList_name}_${index + 1}.txt` : `${songList_name}.txt`;
    // console.log(`handleFileMigration: 第 ${index + 1} 组歌单已格式化，文件名为 ${fileName}`);

    // 使用 chrome.runtime.sendMessage 发送消息给 background script
    try {
      const response = await new Promise((resolve, reject) => {
        chrome.runtime.sendMessage({
          action: 'download',
          blobUrl: URL.createObjectURL(blob),
          filename: fileName
        }, response => {
          if (chrome.runtime.lastError) {
            reject(chrome.runtime.lastError);
          } else {
            resolve(response);
          }
        });
      });
      // console.log(`handleFileMigration: 第 ${index + 1} 组文件下载消息已发送`);

      if (!response || !response.success) {
        throw new Error(response.error || 'Failed to download file.');
      }
    } catch (error) {
      console.error(`handleFileMigration: 第 ${index + 1} 组文件下载失败: ${error.message}`);
      alert(`下载文件失败: ${error.message}`);
      return; // 终止后续下载
    }
  }

  showToast('文件已保存。请发送到手机，在手机上复制文件内容导入。');
  // console.log("handleFileMigration: 文件迁移处理完成");
}

/**
 * 处理二维码迁移操作。
 * 将歌单分组。
 * 生成临时页面的 HTML 内容。
 * 将临时页面内容上传到服务器。
 * 显示二维码。
 * @param {string} songList_name 歌单名称
 * @param {Array} songList 歌曲列表
 */
async function handleQRMigration(songList_name, songList) {
  // console.log("handleQRMigration: 开始处理二维码迁移");
  // 添加防抖检查
  if (isProcessing) {
    // console.log("handleQRMigration: 上次迁移仍在处理中，请稍候");
    showToast('正在处理中，请稍候...');
    return;
  }

  try {
    isProcessing = true; // 设置处理状态
    // console.log("handleQRMigration: 设置处理状态为 true");
    const chunks = platformManager.chunkSongList(songList, dstPlatform);
    // console.log(`handleQRMigration: 歌单已分组，共 ${chunks.length} 组`);
    const tempPageContent = await generateTempPageContent(songList_name, chunks);
    // console.log("handleQRMigration: 临时页面内容生成完成");
    const dialog = document.getElementById('migration-dialog');
    const qrSection = dialog.querySelector('.qr-section');

    // 确保所有属性都被正确赋值
    const stats = {
      timestamp: new Date().toISOString(),
      PlayListName: songList_name,
      SongsCount: songList.length,
      SourcePlatform: srcPlatform,
      TargetPlatform: dstPlatform,
    };
    // console.log("handleQRMigration: 统计信息已创建", stats);

    const result = await window.utils.sendToBackground('uploadToWorker', {
      htmlContent: tempPageContent,
      stats: stats,
    });
    // console.log("handleQRMigration: 临时页面内容已上传");

    if (result && result.result) {
      showQRCode(result.result);
      // console.log("handleQRMigration: 二维码显示完成");
    } else {
      console.error("handleQRMigration: 临时页面上传失败");
      alert('临时页面上传失败，请检查网络连接或稍后重试。');
    }
  } catch (error) {
    console.error(`handleQRMigration: 发生错误: ${error.message}`);
    alert(`错误：${error.message}，请检查网络连接或稍后重试。`);
  } finally {
    isProcessing = false; // 重置处理状态
    // console.log("handleQRMigration: 重置处理状态为 false");
  }
}

/**
 * 生成临时页面的 HTML 内容。
 * 读取 playlist.html 模板文件。
 * 替换占位符，包括标题、歌单名称、歌曲数量、歌曲列表、提示文本等。
 * 根据分组数量决定是否显示“每一组”文本。
 * 动态生成复制按钮和复制事件。
 * @param {string} songList_name 歌单名称
 * @param {Array} chunks 分组后的歌曲列表
 * @returns {Promise<string>} 临时页面的 HTML 内容
 */
async function generateTempPageContent(songList_name, chunks) {
  // console.log("generateTempPageContent: 开始生成临时页面内容");
  const songGroupsHtml = chunks.map((group, index) => {
    // 根据目标平台格式化歌曲列表
    const formattedSongs = platformManager.formatSongList(group, dstPlatform);

    const songsHtml = formattedSongs.split('\n').map(song => `<div class="song-item">${song}</div>`).join('');
    const copyButton = `<button class="copy-button to-copy" id="copyButton${index + 1}">复制这组歌曲</button>`;
    const number = `<div class="number">${index + 1}</div>`;
    return `
      <div class="playlist-card playlist-card-default">
          <div class="song-list">
              ${songsHtml}
          </div>
          <div class="card-song-count">共${formattedSongs.split('\n').length}首歌曲</div>
          ${copyButton}
          ${number}
      </div>
    `;
  }).join('');
  // console.log("generateTempPageContent: 歌曲分组 HTML 生成完成");

  // 读取模板文件
  const response = await fetch(chrome.runtime.getURL('ui/playlist.html'));
  const html = await response.text();
  // console.log("generateTempPageContent: playlist.html 模板文件读取完成");

  // 使用DOMParser解析HTML
  const parser = new DOMParser();
  const doc = parser.parseFromString(html, 'text/html');
  // console.log("generateTempPageContent: playlist.html 模板文件解析完成");

  // 替换占位符
  doc.querySelector('title').textContent = songList_name; // 设置<title>标签
  doc.querySelector('h1').textContent = songList_name;
  // console.log(`generateTempPageContent: 标题已设置为 ${songList_name}`);

  // 在使用chunks.flat()之前，检查chunks是否为空
  if (chunks && chunks.length > 0) {
    doc.querySelector('.song-count').textContent = `共 ${chunks.flat().length} 首歌曲`;
  } else {
    // 处理chunks为空的情况，例如：
    doc.querySelector('.song-count').textContent = `共 0 首歌曲`;
    console.error("chunks数组为空！", chunks); // 打印错误信息到控制台，方便调试
  }
  // console.log("generateTempPageContent: 歌曲数量已设置");

  doc.getElementById('songGroups').innerHTML = songGroupsHtml;
  // console.log("generateTempPageContent: 歌曲分组 HTML 已插入");

  // 根据分组数量决定是否显示“每一组”文本
  const groupText = doc.getElementById('group-text');
  if (chunks.length > 1) {
    groupText.style.display = 'inline'; // 显示“每一组”
  } else {
    groupText.style.display = 'none'; // 隐藏“每一组”
  }
  // console.log("generateTempPageContent: '每一组'文本显示状态已设置");

  const songCountElement = doc.querySelector('.song-count');

  if (songCountElement) {
    songCountElement.textContent = `共 ${chunks.flat().length} 首歌曲`;
  } else {
    console.error("'.song-count' element not found in playlist.html");
  }

  // 根据目标平台设置提示文本
  const platformText = doc.getElementById('platform-text');

  if (platformText) {
    if (dstPlatform === platformManager.Platforms.NETEASE) {
      platformText.textContent = '在网易云音乐中';
    } else if (dstPlatform === platformManager.Platforms.QQ) {
      platformText.textContent = '在QQ音乐中';
    } else {
      platformText.textContent = ''; // 默认文本
    }
  } else {
    console.error("'platform-text' element not found in playlist.html");
  }
  // console.log("generateTempPageContent: 平台提示文本已设置");

  // 将复制相关的函数添加到 <script> 标签中
  doc.querySelector('script').innerHTML = `
    document.addEventListener('DOMContentLoaded', function() {
      const groups = ${JSON.stringify(chunks)};
      const groupText = document.getElementById('group-text');

      if (groups.length > 1) {
          groupText.style.display = 'inline'; // 显示“每一组”
      }

      groups.forEach((group, index) => {
        const button = document.getElementById('copyButton' + (index + 1));
        if (button) {
          button.addEventListener('click', function() {
            // 获取当前按钮对应的歌曲列表的文本内容
            const songList = Array.from(button.parentElement.querySelectorAll('.song-item'))
              .map(item => item.textContent.trim())
              .join('\\n');
            copyToClipboard(songList, button);
          });
        } else {
          console.error('Button not found for group ' + (index + 1));
        }
      });
    });

    function copyToClipboard(text, button) {
      navigator.clipboard.writeText(text)
        .then(() => {
          showToast();
          button.classList.remove('to-copy');
          button.classList.add('copied');
          button.textContent = '已复制';

          // 找到父级 .playlist-card 元素并更改其类
          let card = button.closest('.playlist-card');
          if (card) {
            card.classList.remove('playlist-card-default');
            card.classList.add('playlist-card-copied');
          }
        })
        .catch(err => console.error('Failed to copy: ', err));
    }

    function showToast() {
      const toast = document.getElementById('toast');
      toast.style.display = 'block';
      setTimeout(() => {
        toast.style.display = 'none';
      }, 2000);
    }
  `;
  // console.log("generateTempPageContent: 复制相关脚本已插入");

  // 返回最终的HTML内容
  // console.log("generateTempPageContent: 临时页面内容生成完成");
  return doc.documentElement.outerHTML;
}

/**
 * 显示toast提示
 * @param {string} message 要显示的消息内容
 */
function showToast(message = '操作成功') {
  // console.log(`showToast: 显示提示信息: ${message}`);
  // 加载popup.css文件
  const linkElement = document.createElement('link');
  linkElement.rel = 'stylesheet';
  linkElement.href = chrome.runtime.getURL('ui/popup.css');
  document.head.appendChild(linkElement);
  // console.log("showToast: popup.css 加载完成");

  // 移除可能存在的旧toast
  const oldToast = document.getElementById('toast');
  if (oldToast && oldToast.parentNode === document.body) {
    document.body.removeChild(oldToast);
    // console.log("showToast: 旧的 toast 提示已移除");
  }

  // 创建新的toast元素
  const toast = document.createElement('div');
  toast.id = 'toast';
  toast.className = 'toast';
  toast.textContent = message;

  // 将toast添加到body中
  document.body.appendChild(toast);
  // console.log("showToast: 新的 toast 提示已添加到页面");

  // 强制重绘以确保动画生效
  void toast.offsetWidth;

  // 显示toast
  toast.style.display = 'block';
  // console.log("showToast: toast 提示已显示");

  // 2秒后隐藏并移除toast
  setTimeout(() => {
    toast.style.display = 'none';
    setTimeout(() => {
      if (toast.parentNode === document.body) {
        document.body.removeChild(toast);
        // console.log("showToast: toast 提示已移除");
      }
      // 移除添加到页面的link标签
      document.head.removeChild(linkElement);
      // console.log("showToast: popup.css link 标签已移除");
    }, 300); // 等待动画完成
  }, 2000);
}

// 运行脚本
if (platformManager.getCurrentPlatform() !== null) {
  // console.log("content.js: 页面平台已识别，开始添加迁移按钮");
  addMigrateButton();

  // 监听歌单切换事件
  platformManager.setupPlaylistChangeListener(platformManager.getCurrentPlatform(), () => {
    // 使用 platformManager.isPlaylistPage() 检查当前页面是否为歌单页面
    if (platformManager.isPlaylistPage(platformManager.getCurrentPlatform())) {
      // console.log("content.js: 歌单页面已切换");
      // 如果存在迁移对话框，则更新对话框内容，否则隐藏对话框
      if (document.getElementById('migration-dialog')) {
        updateMigrationDialog();
      }
    }
  });
}
