/*
 * File: platformManager.js
 * Project: extension
 * Created: 2024-12-19 10:13:06
 * Author: Victor Cheng
 * Email: greenzorromail@gmail.com
 * Description: 平台管理模块，负责处理不同音乐平台的逻辑。
 */

// 定义平台枚举
const Platforms = {
  QQ: 'qq',
  NETEASE: 'netease'
};

/**
 * 获取当前音乐平台的标识。
 * @returns {string|null} 当前音乐平台的标识，如果无法识别则返回 null。
 */
function getCurrentPlatform() {
  const currentUrl = window.location.href;
  if (currentUrl.includes('y.qq.com')) {
    return Platforms.QQ;
  } else if (currentUrl.includes('music.163.com')) {
    return Platforms.NETEASE;
  } else {
    return null;
  }
}

/**
 * 检查当前URL是否是支持的音乐平台页面。
 * @returns {boolean} 如果是支持的平台则返回 true，否则返回 false。
 */
function isSupportedPage() {
  const currentUrl = window.location.href;
  return currentUrl.startsWith('https://y.qq.com/n/ryqq/playlist/') ||
    currentUrl.startsWith('https://y.qq.com/musicmac/v6/playlist/detail.html?id=') ||
    currentUrl.startsWith('https://music.163.com/#/my/m/music/playlist?id=');
}

/**
 * 检查当前页面是否为歌单页面。
 * @param {string} platform 平台标识。
 * @returns {boolean} 如果是歌单页面，则返回 true，否则返回 false。
 */
function isPlaylistPage(platform) {
  if (platform === Platforms.NETEASE) {
    return isNeteasePlaylistPage();
  } else if (platform === Platforms.QQ) {
    // 如果需要，可以在这里添加 QQ 音乐的歌单页面判断逻辑
    return isSupportedPage(); // 使用 isSupportedPage 作为 QQ 音乐歌单页面的判断
  }
  return false;
}

/**
 * 检查当前页面是否为网易云音乐歌单页面。
 * @returns {boolean} 如果是网易云音乐歌单页面，则返回 true，否则返回 false。
 */
function isNeteasePlaylistPage() {
  return window.location.href.startsWith('https://music.163.com/#/my/m/music/playlist?id=');
}

/**
 * 检查用户是否已登录。
 * @param {string} platform 平台标识。
 * @returns {boolean} 如果用户已登录，则返回 true，否则返回 false。
 */
function isUserLoggedIn(platform) {
  console.log("当前平台: ", platform); // 打印当前平台信息
  if (platform === Platforms.QQ) {
    // 对于 y.qq.com，不需要登录
    return true
  } else if (platform === Platforms.NETEASE) {
    // 对于 music.163.com，查找页面上有没有 data-action="login" 的dom，没有就算已登录
    return !document.querySelector('[data-action="login"]');
  }
  return false; // 默认返回false，表示未登录
}

/**
 * 从当前页面URL中提取QQ音乐歌单ID。
 * @returns {string|null} 如果找到歌单ID则返回字符串形式的ID，否则返回null。
 */
function extractQQPlaylistIdFromUrl() {
  const url = window.location.href;
  const match = url.match(/https:\/\/y\.qq\.com\/n\/ryqq\/playlist\/(\d+)/);
  return match ? match[1] : null;
}

/**
 * 监听网易云音乐歌单切换事件。
 * @param {Function} callback 当检测到歌单切换时执行的回调函数。
 */
function setupNeteasePlaylistChangeListener(callback) {
  const iframe = document.querySelector('iframe#g_iframe');
  if (iframe) {
    let lastUrl = ''; // 用于存储上一次检测到的 URL

    setInterval(() => {
      // 检查当前 URL 是否为歌单页面 且 URL 发生了变化
      if (isNeteasePlaylistPage() && iframe.contentWindow.location.href !== lastUrl) {
        lastUrl = iframe.contentWindow.location.href; // 更新 lastUrl
        callback();
      }
    }, 1000); // 每秒检查一次
  }
}

/**
 * 监听歌单切换事件。
 * @param {string} platform 平台标识。
 * @param {Function} callback 当检测到歌单切换时执行的回调函数。
 */
function setupPlaylistChangeListener(platform, callback) {
  if (platform === Platforms.NETEASE) {
    setupNeteasePlaylistChangeListener(callback);
  } else if (platform === Platforms.QQ) {
    // 如果需要，可以在这里添加 QQ 音乐的歌单切换监听逻辑
  }
}

/**
 * 从QQ音乐的HTML内容中提取歌曲列表。
 * @param {Document} htmlContent  包含歌曲信息的HTML文档
 * @returns {Array}  歌曲列表
 */
function extractQQSongListFromHTML(htmlContent) {
  let songList = [];
  const songListElement = htmlContent.querySelectorAll('.songlist__item');
  if (songListElement.length > 0) {
    songListElement.forEach(song => {
      const resName = song.querySelector('.mod_songname__name').textContent.trim();
      const resAuthor = song.querySelector('.songlist__singer').textContent.trim();
      songList.push({ name: resName, artist: resAuthor });
    });
  }
  return songList;
}

/**
 * 从网易云音乐的HTML内容中提取歌曲列表。
 * @param {Document} htmlContent 包含歌曲信息的HTML文档
 * @returns {Array} 歌曲列表
 */
function extractNeteaseSongListFromHTML(htmlContent) {
  let songList = [];
  const trList = htmlContent.querySelectorAll('tbody>tr');
  trList.forEach(tr => {
    const resId = tr.querySelector('[data-res-id]');
    if (resId) {
      const soilElements = tr.querySelectorAll('.soil');
      soilElements.forEach(soil => soil.remove());
      const resNameElement = tr.querySelector('a[href*="song?id="] b');
      const resName = resNameElement ? resNameElement.textContent.replace(/\n/g, '') : '';
      const resAuthorElement = tr.querySelector('a[href*="artist?id="]');
      const resAuthor = resAuthorElement ? resAuthorElement.parentElement.title.replace(/\n/g, '') : '';
      songList.push({ name: resName, artist: resAuthor });
    }
  });
  return songList;
}

/**
 * 从QQ音乐提取歌单名称和歌曲列表。
 * @returns {Promise<[string, Array]>} 一个包含歌单名称和歌曲列表的数组，数组第一个元素为歌单名称，第二个元素为歌曲列表。
 */
async function extractQQSongList() {
  // 获取歌单名称
  let songList_name = document.querySelector('h1.mod_data__name_txt').textContent.trim();
  // 获取歌曲列表
  let songList = extractQQSongListFromHTML(document);
  console.log("songList: ", songList);
  return [songList_name, songList];
}

/**
 * 从网易云音乐提取歌单名称和歌曲列表。
 * @returns {Promise<[string, Array]>} 一个包含歌单名称和歌曲列表的数组，数组第一个元素为歌单名称，第二个元素为歌曲列表。
 */
async function extractNeteaseSongList() {
  return new Promise((resolve) => {
    const iframe = document.querySelector('iframe#g_iframe');
    let songList_name = "";
    let songList = [];

    if (iframe) {
      // 监听 iframe 的 load 事件
      iframe.addEventListener('load', () => {
        console.log('iframe loaded'); // 添加调试信息
        extractDataFromIframe();
      });

      const extractDataFromIframe = () => {
        const iframeContent = iframe.contentDocument;
        if (iframeContent && iframeContent.querySelector('.m-info h2') && iframeContent.querySelectorAll('tbody>tr').length > 0) {
          // 获取歌单名称
          songList_name = iframeContent.querySelector('.m-info h2').textContent.trim();

          // 获取歌曲列表
          songList = extractNeteaseSongListFromHTML(iframeContent);

          resolve([songList_name, songList]);
        } else {
          // 如果内容还未加载完成，继续等待
          setTimeout(extractDataFromIframe, 500);
        }
      };

      // 首次加载时也尝试提取数据
      extractDataFromIframe();
    } else {
      resolve([songList_name, songList]);
    }
  });
}

/**
 * 根据来源平台提取歌单信息。
 * @param {string} srcPlatform 来源平台标识。
 * @returns {Promise<[string, Array]>} 一个包含歌单名称和歌曲列表的数组，数组第一个元素为歌单名称，第二个元素为歌曲列表。如果平台不受支持，则返回一个空数组。
 */
async function extractSongList(srcPlatform) {
  if (srcPlatform === Platforms.QQ) {
    // 检查当前页面是否已经是完整歌单详情页
    if (!window.location.href.startsWith(`https://y.qq.com/musicmac/v6/playlist/detail.html?id=`)) {
      // 获取歌单ID
      const playlistId = extractQQPlaylistIdFromUrl();
      if (!playlistId) {
        alert('无法从 URL 中提取歌单 ID。');
        return;
      }
      // 导航到完整歌单详情页
      window.location.href = `https://y.qq.com/musicmac/v6/playlist/detail.html?id=${playlistId}`;
      await new Promise(resolve => setTimeout(resolve, 5000)); // 等待页面加载
    }
    return await extractQQSongList();
  } else if (srcPlatform === Platforms.NETEASE) {
    return await extractNeteaseSongList();
  } else {
    return ['', []]; // 或者抛出错误，表示不支持的平台
  }
}

/**
 * 将歌曲列表分组以适配QQ音乐，每组歌曲名称和歌手名总长度不超过1000个字符。
 * @param {Array} songList 歌曲列表，每个元素包含name和artist属性。
 * @returns {Array} 分组后的歌曲列表。
 */
function chunkSongListForQQ(songList) {
  const chunks = [];
  let currentChunk = [];
  let currentChunkLength = 0;

  songList.forEach(song => {
    const songLength = `${song.name} - ${song.artist}`.length + 1; // +1 for newline character
    // QQ Music: 1000 characters per chunk
    if (currentChunkLength + songLength > 1000) {
      chunks.push(currentChunk);
      currentChunk = [];
      currentChunkLength = 0;
    }
    currentChunk.push(song);
    currentChunkLength += songLength;
  });

  if (currentChunk.length > 0) {
    chunks.push(currentChunk);
  }

  return chunks;
}

/**
 * 将歌曲列表分组以适配网易云音乐，每组最多包含100首歌曲。
 * @param {Array} songList 歌曲列表，每个元素包含name和artist属性。
 * @returns {Array} 分组后的歌曲列表。
 */
function chunkSongListForNetease(songList) {
  const chunks = [];
  let currentChunk = [];

  songList.forEach(song => {
    // NetEase Cloud Music: 100 songs per chunk
    if (currentChunk.length >= 100) {
      chunks.push(currentChunk);
      currentChunk = [];
    }
    currentChunk.push(song);
  });

  if (currentChunk.length > 0) {
    chunks.push(currentChunk);
  }

  return chunks;
}

/**
 * 根据目标平台将歌曲列表分割成块。
 * @param {Array} songList 歌曲列表。
 * @param {string} dstPlatform 目标平台标识。
 * @returns {Array} 分块后的歌曲列表。如果平台不受支持，则返回一个空数组。
 */
function chunkSongList(songList, dstPlatform) {
  if (dstPlatform === Platforms.QQ) {
    return chunkSongListForQQ(songList);
  } else if (dstPlatform === Platforms.NETEASE) {
    return chunkSongListForNetease(songList);
  } else {
    return []; // 或者抛出错误，表示不支持的平台
  }
}

/**
 * 格式化歌曲列表为适用于 QQ 音乐的字符串，每行一首歌，格式为“歌手《歌名》”。
 * @param {Array} songList 歌曲列表。
 * @returns {string} 格式化后的歌曲列表字符串。
 */
function formatSongListForQQ(songList) {
  return songList.map(song => `${song.artist}《${song.name}》`).join('\n');
}

/**
 * 格式化歌曲列表为适用于网易云音乐的字符串，每行一首歌，格式为“歌名 - 歌手”。
 * @param {Array} songList 歌曲列表。
 * @returns {string} 格式化后的歌曲列表字符串。
 */
function formatSongListForNetease(songList) {
  return songList.map(song => `${song.name} - ${song.artist}`).join('\n');
}

/**
 * 根据目标平台格式化歌曲列表。
 * @param {Array} songList 歌曲列表。
 * @param {string} dstPlatform 目标平台标识。
 * @returns {string} 格式化后的歌曲列表。如果平台不受支持，则返回一个空字符串。
 */
function formatSongList(songList, dstPlatform) {
  if (dstPlatform === Platforms.QQ) {
    return formatSongListForQQ(songList);
  } else if (dstPlatform === Platforms.NETEASE) {
    return formatSongListForNetease(songList);
  } else {
    return ''; // 或者抛出错误，表示不支持的平台
  }
}

// 将需要使用的函数和变量添加到全局对象中（例如 window）
window.platformManager = {
  Platforms,
  getCurrentPlatform,
  isSupportedPage,
  isPlaylistPage,
  isUserLoggedIn,
  setupPlaylistChangeListener,
  extractQQSongListFromHTML,
  extractNeteaseSongListFromHTML,
  extractSongList,
  chunkSongList,
  formatSongList
};
