/*
 * File: utils.js
 * Project: extension
 * Created: 2024-12-11 06:05:22
 * Author: Victor Cheng
 * Email: greenzorromail@gmail.com
 * Description: 工具函数
 */

/**
 * 清理非法字符，将 < > : " / \ | ? * . , 替换为空格，并将多个连续空格替换为单个空格
 * @param {string} input_string 输入的字符串
 * @returns {string} 清理后的字符串
 */
function sanitizeFileName(input_string) {
  const invalid_chars_for_file_name = ['<', '>', ':', '"', '/', '\\', '|', '?', '*', '.', ','];
  const invalid_chars_for_songlist = ['·'];
  const invalid_chars = [...new Set([...invalid_chars_for_file_name, ...invalid_chars_for_songlist])];
  for (const char of invalid_chars) {
    input_string = input_string.replace(new RegExp('\\' + char, 'g'), ' ');
  }
  // 把多个连续的空格替换单个空格
  const result = input_string.split(/\s+/).join(' ');
  return result;
}

/**
 * 使用 qrcode.js 生成二维码
 * @param {HTMLElement} container 用于显示二维码的DOM元素
 * @param {string} text 二维码中包含的文本内容
 * @param {number} size 二维码的尺寸（宽度和高度相同）
 */
function GenerateQRCode(container, text, size) {
  // 参考：https://github.com/davidshimjs/qrcodejs
  new QRCode(container, {
    text: text,
    width: size,
    height: size,
    colorDark: "#000000",
    colorLight: "#ffffff",
    correctLevel: QRCode.CorrectLevel.H
  });
}

/**
 * 向浏览器插件后台脚本发送消息，并处理可能的错误
 * @param {string} action 操作名称
 * @param {any} data 要发送的数据
 * @returns {Promise<any>} 包含后台脚本响应的 Promise，如果后台脚本返回错误，则 Promise 会被 reject
 */
function sendToBackground(action, data) {
  return new Promise((resolve, reject) => {
    chrome.runtime.sendMessage({ action, content: data }, response => {
      if (response && response.error) {
        reject(new Error(response.error));
      } else {
        resolve(response);
      }
    });
  });
}

// 将工具函数添加到 window.utils 对象中
window.utils = {
  sanitizeFileName,
  GenerateQRCode,
  sendToBackground
};